==> haskell-unix-compat-0.6-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unix-compat
version:              0.6
visibility:           public
id:                   unix-compat-0.6-6MS1TAZj5el1z02sqr4ctn
key:                  unix-compat-0.6-6MS1TAZj5el1z02sqr4ctn
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             http://github.com/jacobstanley/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  1482edcbc272c662ce4a841a52b23b65
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Temp
    System.PosixCompat.Time System.PosixCompat.Types
    System.PosixCompat.Unistd System.PosixCompat.User

import-dirs:          /usr/lib/ghc-9.0.2/site-local/unix-compat-0.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unix-compat-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-compat
hs-libraries:         HSunix-compat-0.6-6MS1TAZj5el1z02sqr4ctn
include-dirs:         /usr/lib/ghc-9.0.2/site-local/unix-compat-0.6/include
includes:             HsUnixCompat.h
depends:              base-4.15.1.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-compat-0.6-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unix-compat
version:              0.6
visibility:           public
id:                   unix-compat-0.6-JBzTnpJ41UsJRnHDQ8QuC4
key:                  unix-compat-0.6-JBzTnpJ41UsJRnHDQ8QuC4
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             http://github.com/jacobstanley/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  ad8066b0d5965b16b3b701c9bdb3416b
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Temp
    System.PosixCompat.Time System.PosixCompat.Types
    System.PosixCompat.Unistd System.PosixCompat.User

import-dirs:          /usr/lib/ghc-9.0.2/site-local/unix-compat-0.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unix-compat-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-compat
hs-libraries:         HSunix-compat-0.6-JBzTnpJ41UsJRnHDQ8QuC4
include-dirs:         /usr/lib/ghc-9.0.2/site-local/unix-compat-0.6/include
includes:             HsUnixCompat.h
depends:              base-4.15.1.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
